pub struct ActivityUpdate(pub Activity);Expand description
Event which updates the current Discord activity
Tuple Fields
0: ActivityTrait Implementations
Sourceimpl Component for ActivityUpdate
impl Component for ActivityUpdate
Sourceconst STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::SparseSet
const STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::SparseSet
A constant indicating the storage type used for this component.
Sourcefn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its
ComponentHooks.Sourceimpl Default for ActivityUpdate
Generate a default ActivityUpdate instance with an empty Activity struct
impl Default for ActivityUpdate
Generate a default ActivityUpdate instance with an empty Activity struct
Sourceimpl Deref for ActivityUpdate
impl Deref for ActivityUpdate
impl Event for ActivityUpdate